@@ -176,5 +176,5 @@ class ThingHTTP:
 
     def __get_headers(self):
         return {
-            "Authorization": "bearer " + str(self.thing.token.get_token())
+            "Authorization": "bearer " + self.thing.token.get_token()
         }
